@@ -4,7 +4,7 @@
              (or (file-name-directory load-file-name) (car load-path)))
 
 ;;;### (autoloads (sml-yacc-mode sml-lex-mode sml-cm-mode sml-mode)
-;;;;;;  "sml-mode" "sml-mode.el" (19344 19039))
+;;;;;;  "sml-mode" "sml-mode.el" (20358 8148))
 ;;; Generated autoloads from sml-mode.el
 
 (add-to-list 'auto-mode-alist '("\\.s\\(ml\\|ig\\)\\'" . sml-mode))
@@ -37,17 +37,23 @@ Major Mode for editing ML-Yacc files.
 
 \(fn)" t nil)
 
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "sml-mode" '("font-lock-type-def-face" "font-lock-module-def-face" "font-lock-interface-def-face")))
+
 ;;;***
 
-;;;### (autoloads nil "sml-proc" "sml-proc.el" (19344 5059))
+;;;### (autoloads nil "sml-oldindent" "sml-oldindent.el" (20358 8148))
+;;; Generated autoloads from sml-oldindent.el
+
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "sml-oldindent" '("sml-")))
+
+;;;***
+
+;;;### (autoloads nil "sml-proc" "sml-proc.el" (20358 8148))
 ;;; Generated autoloads from sml-proc.el
 
 (autoload 'run-sml "sml-proc" nil t)
 
-;;;***
-
-;;;### (autoloads nil nil ("sml-compat.el" "sml-defs.el" "sml-move.el"
-;;;;;;  "sml-util.el") (19344 21563 982091))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "sml-proc" '("sml-" "inferior-sml-" "font-lock-" "run-sml" "switch-to-sml")))
 
 ;;;***
 
